<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Vpc_Ssa
 * @subpackage Vpc_Ssa/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Ssa
 * @subpackage Vpc_Ssa/admin
 * @author     Orion <freelance@orionorigin.com>
 */
class Vpc_Ssa_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param string $plugin_name       The name of this plugin.
	 * @param string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Ssa_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Ssa_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( class_exists( 'vpc' ) ) {
			if ( is_vpc_admin_screen() ) {
				wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/vpc-ssa-admin.css', array(), VPC_SSA_VERSION, 'all' );
			}
		}
	}

	/**
	 * Runs the new version check and upgrade process
	 *
	 * @return \Vpc_Ssa_Updater
	 */
	public function get_updater() {
		if ( class_exists( 'vpc' ) ) {
			do_action( 'vpc_before_init_updater' );
			require_once VPC_SSA_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-ssa-updater.php';
			$updater = new Vpc_Ssa_Updater();
			$updater->init();
			require_once VPC_SSA_DIR . DIRECTORY_SEPARATOR . 'includes' . DIRECTORY_SEPARATOR . 'updaters' . DIRECTORY_SEPARATOR . 'class-vpc-ssa-updating-manager.php';
			$updater->set_update_manager( new Vpc_Ssa_Updating_Manager( VPC_SSA_VERSION, $updater->version_url(), VPC_SSA_MAIN_FILE ) );
			do_action( 'vpc_after_init_updater' );
			return $updater;
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Ssa_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Ssa_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	}

	/**
	 * Function to add social share settings.
	 *
	 * @param array $skin_settings The social share settings parameter.
	 * @return array
	 */
	public function add_social_share_settings( $skin_settings ) {
		$skin_settings[] = array(
			'type' => 'sectionbegin',
			'id'   => 'vpc-ssa-container',
		);
		$skin_settings[] = array(
			'title'   => __( 'Activate Social share option', 'vpc-ssa' ),
			'name'    => 'vpc-config[social-share]',
			'type'    => 'radio',
			'options' => array(
				'Yes' => 'Yes',
				'No'  => 'No',
			),
			'default' => 'No',
			'class'   => '',
			'desc'    => __( 'Choose YES to activate the Social share options (<a href=“https://orionorigin.com/guide/social-sharing-add-on/“ target=“_blank”>Learn more</a>)', 'vpc-ssa' ),
		);
		$skin_settings[] = array( 'type' => 'sectionend' );
		return $skin_settings;
	}

	/**
	 * Function to add ssa global ettings.
	 *
	 * @param array $settings The ssa settings parameter.
	 * @return array
	 */
	public function add_ssa_global_settings( $settings ) {
		// Récupérer les settings existants et affecter les valeurs aux options de social share
		// debut.
		$old_data            = get_option( 'vpc-options' );
		$default_share_time  = 0;
		$default_share_desc  = 0;
		$default_facebook_id = 0;
		$default_facebook    = 0;
		$default_twitter     = 0;
		$default_pinterest   = 0;
		$default_mail        = 0;

		if ( $old_data ) {
			if ( isset( $old_data['share-time'] ) ) {
				$default_share_time = $old_data['share-time'];
			} else {
				$default_share_time = 0;
			}
			if ( isset( $old_data['facebook_id'] ) ) {
				$default_facebook_id = $old_data['facebook_id'];
			} else {
				$default_facebook_id = '';
			}
			if ( isset( $old_data['share-desc'] ) ) {
				$default_share_desc = $old_data['share-desc'];
			} else {
				$default_share_desc = '';
			}
			if ( isset( $old_data['share-title-desc'] ) ) {
				$default_title_desc = $old_data['share-title-desc'];
			} else {
				$default_title_desc = '';
			}
			if ( isset( $old_data['purchase-code-social-share-add-on'] ) ) {
				$default_purchase_code_social_share_add_on = $old_data['purchase-code-social-share-add-on'];
			} else {
				$default_purchase_code_social_share_add_on = '';
			}
			if ( isset( $old_data['facebook'] ) ) {
				$default_facebook = $old_data['facebook'];
			} else {
				$default_facebook = 0;
			}
			if ( isset( $old_data['twitter'] ) ) {
				$default_twitter = $old_data['twitter'];
			} else {
				$default_twitter = 0;
			}
			if ( isset( $old_data['pinterest'] ) ) {
				$default_pinterest = $old_data['pinterest'];
			} else {
				$default_pinterest = 0;
			}
			if ( isset( $old_data['mail'] ) ) {
				$default_mail = $old_data['mail'];
			} else {
				$default_mail = 0;
			}
		}
		// fin.

		$bg_ssa_settings = array(
			'type' => 'sectionbegin',
			'id'   => 'ssa-global-container',
		);

		$end_ssa_settings = array( 'type' => 'sectionend' );

		$ssa_time = array(
			'title'   => __( 'Shared configuration on social networks (hours)', 'vpc-ssa' ),
			'name'    => 'vpc-options[share-time]',
			'class'   => 'ssa-time',
			'type'    => 'number',
			'default' => $default_share_time,
			'desc'    => __( 'The number of hours before the shared configuration on social networks will expire. Leave the value at zero (0) so that the link never expires', 'vpc-ssa' ),
		);

		$license_key = array(
			'title'   => __( 'Social Share add on license key', 'vpc' ),
			'name'    => 'vpc-options[purchase-code-social-share-add-on]',
			'type'    => 'text',
			'desc'    => __( 'This is the licence key you received after your purchase.<a href=“https://orionorigin.com/guide/how-to-add-my-license/” target=“_blank”>Learn more</a>. <a href=“https://orionorigin.com/my-account/orders/“ target=“blank”>Where can I find my license key</a>?', 'vpc' ),
			'default' => $default_purchase_code_social_share_add_on,
		);

		$ssa_facebook_id = array(
			'title'   => __( 'Facebook page id', 'vpc-ssa' ),
			'name'    => 'vpc-options[facebook_id]',
			'class'   => 'ssa-facebook_id',
			'type'    => 'text',
			'default' => $default_facebook_id,
			'desc'    => __( 'Enter the Facebook page ID of the page you want to connect to the plugin', 'vpc-ssa' ),
		);

		$ssa_title_desc = array(
			'title'   => __( 'Title used in the share messages', 'vpc-ssa' ),
			'name'    => 'vpc-options[share-title-desc]',
			'class'   => 'ssa-desc',
			'type'    => 'text',
			'default' => $default_title_desc,
			'desc'    => __( 'Add the standard title for the shared content ', 'vpc-ssa' ),
		);

		$ssa_desc = array(
			'title'   => __( 'Text used in the share messages', 'vpc-ssa' ),
			'name'    => 'vpc-options[share-desc]',
			'class'   => 'ssa-desc',
			'type'    => 'text',
			'default' => $default_share_desc,
			'desc'    => __( 'Add a standard description for the shared content', 'vpc-ssa' ),
		);

		$facebook = array(
			'title'   => __( 'Facebook', 'vpc-ssa' ),
			'name'    => 'vpc-options[facebook]',
			'class'   => 'ssa-network',
			'type'    => 'checkbox',
			'value'   => 1,
			'default' => $default_facebook,
		);

		$twitter = array(
			'title'   => __( 'Twitter', 'vpc-ssa' ),
			'name'    => 'vpc-options[twitter]',
			'class'   => 'ssa-network',
			'type'    => 'checkbox',
			'value'   => 1,
			'default' => $default_twitter,
		);

		$pinterest = array(
			'title'   => __( 'Pinterest', 'vpc-ssa' ),
			'name'    => 'vpc-options[pinterest]',
			'class'   => 'ssa-network',
			'type'    => 'checkbox',
			'value'   => 1,
			'default' => $default_pinterest,
		);
		$mail      = array(
			'title'   => __( 'Mail', 'vpc-ssa' ),
			'name'    => 'vpc-options[mail]',
			'class'   => 'ssa-network',
			'type'    => 'checkbox',
			'value'   => 1,
			'default' => $default_mail,
		);

		$social_network = array(
			'title'  => 'Social Networks',
			'type'   => 'groupedfields',
			'fields' => array( $facebook, $twitter, $pinterest, $mail ),
			'desc'   => __( 'Select the networks you want to use', 'vpc-ssa' ),
		);

		array_push( $settings, $bg_ssa_settings );
		array_push( $settings, $license_key );
		array_push( $settings, $ssa_facebook_id );
		array_push( $settings, $ssa_title_desc );
		array_push( $settings, $ssa_desc );
		array_push( $settings, $social_network );
		array_push( $settings, $end_ssa_settings );
		return $settings;
	}

	/**
	 * Function to add ssa settings onglet.
	 *
	 * @param array  $tabs_group   A group table.
	 * @param string $group_key    A group key.
	 * @param array  $group_value  ssa setting content.
	 * @param string $active_tab   table active value.
	 */
	public function add_ssa_global_onglet( $tabs_group, $group_key, $group_value, $active_tab ) {
		if ( 'ssa-global-container' === $group_key ) {
			?><a href="<?php echo esc_url( admin_url( 'edit.php?post_type=vpc-config&page=vpc-manage-settings&section=ssa-global-container' ) ); ?>" class="nav-tab <?php echo 'ssa-global-container' === $active_tab ? 'nav-tab-active' : ''; ?>"><?php esc_html_e( 'Social Share Addon', 'vpc-ssa' ); ?></a>
			<?php
		}
	}

	/**
	 * Function to add ssa settings onglet.
	 *
	 * @param array  $tabs_group   A group table.
	 * @param string $group_key    A group key.
	 * @param array  $group_value  ssa setting content.
	 * @param string $active_tab   table active value.
	 */
	public function add_ssa_setting_onglet( $tabs_group, $group_key, $group_value, $active_tab ) {
		if ( 'ssa-global-container' === $group_key ) {
			?>
		<a href="<?php echo esc_url( admin_url( 'edit.php?post_type=vpc-config&page=vpc-manage-settings&section=ssa-global-container' ) ); ?>" class="nav-tab <?php echo 'ssa-global-container' === $active_tab ? 'nav-tab-active' : ''; ?>"><?php esc_html_e( 'Social Share Addon', 'vpc-ssa' ); ?></a>
			<?php
		}
	}

	/**
	 * Function to add ssa settings onglet.
	 *
	 * @param array  $tabs_group   A group table.
	 * @param string $group_key    A group key.
	 * @param array  $group_value  ssa setting content.
	 * @param string $active_tab   table active value.
	 */
	public function add_ssa_setting_body( $tabs_group, $group_key, $group_value, $active_tab ) {
		if ( strstr( $group_key, 'ssa-global' ) ) {
			if ( isset( $group_value ) && ! empty( $group_value ) && 'ssa-global-container' === $active_tab ) {
				?>
		<div class="vpc-addons">
				<?php
				echo wp_kses( o_admin_fields( $group_value ), get_allowed_tags() );
				?>
		</div>
				<?php
			}
		}
	}

}
