<?php
/**
 * The file that defines all the global functions
 *
 * @link       https://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Vpc_Ssa
 * @subpackage Vpc_Ssa/includes
 */

/**
 * Function to clean a configuration's recap.
 *
 * @param  array $dirty_recap Unclean configuration recap.
 * @return array              Clean configuration's recap.
 */
function vpc_ssa_clean_recap( $dirty_recap ) {
	$recap = array();
	if ( ! empty( $dirty_recap ) ) {
		$recap = $dirty_recap;
		if ( isset( $recap['action'] ) ) {
			unset( $recap['action'] );
		}
		if ( isset( $recap['nonce'] ) ) {
			unset( $recap['nonce'] );
		}
		if ( isset( $recap['id_ofb'] ) ) {
			unset( $recap['id_ofb'] );
		}

		foreach ( $dirty_recap as $key => $value ) {
			if ( '' === $value ) {
				unset( $recap[ $key ] );
				$text_properties = $key . ' properties';
				if ( isset( $recap[ $text_properties ] ) ) {
					unset( $recap[ $text_properties ] );
				}
			}
		}
	}
	return $recap;
}

/**
 * Function to sanitize an array.
 *
 * @param  array $data Unsanitized array.
 * @return array        Sanitized array.
 */
function vpc_ssa_sanitize_array( $data ) {
	if ( is_array( $data ) ) {
		foreach ( (array) $data as $k => $v ) {
			if ( is_array( $v ) ) {
				$data[ $k ] = vpc_ssa_sanitize_array( $v );
			} else {
				$data[ $k ] = sanitize_text_field( $v );
			}
		}
	} else {
		$data = sanitize_text_field( $data );
	}
	return $data;
}

add_action( 'template_redirect', 'remove_yoast_meta_tags' );

/**
 * Function to remove yoast seo meta tag.
 */
function remove_yoast_meta_tags() {
	global $vpc_settings;
	$vpc_page_id = '';
	if ( class_exists( 'vpc' ) ) {
		$vpc_page_id = get_proper_value( $vpc_settings, 'config-page', false );
	}
	$current_page_id = get_the_ID();
	$post            = get_post( $current_page_id );
	if ( $current_page_id === $vpc_page_id || ( is_object( $post ) && has_shortcode( $post->post_content, 'wpb_builder' ) ) || ( is_object( $post ) && has_shortcode( $post->post_content, 'vpc' ) ) ) {

		/*	 * Facebook. */

		add_filter( 'wpseo_canonical', '__return_false' );
		add_filter( 'wpseo_opengraph_title', '__return_false' );
		add_filter( 'wpseo_opengraph_url', '__return_false' );
		add_filter( 'wpseo_image', '__return_false' );
		add_filter( 'wpseo_opengraph_desc', '__return_false' );
		add_filter( 'wpseo_opengraph_image', '__return_false' );

		/*	 * Twitter */

		add_filter( 'wpseo_twitter_card_type', '__return_false' );
		add_filter( 'wpseo_twitter_image', '__return_false' );
		add_filter( 'wpseo_twitter_title', '__return_false' );
	}
}
