<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://www.orionorigin.com/
 * @since      1.0.0
 *
 * @package    Vpc_Ssa
 * @subpackage Vpc_Ssa/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Vpc_Ssa
 * @subpackage Vpc_Ssa/public
 * @author     Orion <freelance@orionorigin.com>
 */
class Vpc_Ssa_Public
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Ssa_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Ssa_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style('vpc-ssa-public-css', plugin_dir_url(__FILE__) . 'css/vpc-ssa-public.css', array(), VPC_SSA_VERSION, 'all');
		wp_enqueue_style('qtip_min_css', plugin_dir_url(__FILE__) . 'css/jquery.qtip.min.css', array(), VPC_SSA_VERSION, 'all');
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Vpc_Ssa_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Vpc_Ssa_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_script('vpc-ssa-public-js', plugin_dir_url(__FILE__) . 'js/vpc-ssa-public.js', array('jquery'), VPC_SSA_VERSION, false);
		wp_enqueue_script('qtip_min_js', plugin_dir_url(__FILE__) . 'js/jquery.qtip.min.js', array('jquery'), VPC_SSA_VERSION, false);
	}

	/**
	 * Function to get save for later button.
	 *
	 * @param string $prod_id    The product id.
	 * @return string
	 */
	public function get_ssa_buttons($prod_id)
	{
		$sharebtn = '';
		if (!get_option('vpc-social-share-add-on-license-key')) {
			echo "<h2 class='error_msg'>You have not activated your license yet. Please, activate it in order to use Social share add on.</h2>";
		} else {

			$config = $this->get_vpc_ssa_config_data($prod_id);
			if (isset($config['social-share']) && 'Yes' === $config['social-share']) {
				$sharebtn = '<button id="vpc-share" class="btn_share" >' . __('Share on', 'vpc-sfla') . '
				</button>';
				$sharebtn = apply_filters('vpc_share_config_btn', $sharebtn, $prod_id);
			}
		}
		return $sharebtn;
	}

	/**
	 * Ssa configuration datas.
	 *
	 * @param string $prod_id    The product id.
	 * @return array
	 */
	private function get_vpc_ssa_config_data($prod_id)
	{
		$ids         = get_product_root_and_variations_ids($prod_id);
		$config_meta = get_post_meta($ids['product-id'], 'vpc-config', true);
		$configs     = get_proper_value($config_meta, $prod_id, array());
		$config_id   = get_proper_value($configs, 'config-id', false);
		$config      = get_post_meta($config_id, 'vpc-config', true);
		return $config;
	}

	/**
	 * Opengraph function.
	 *
	 * @param string $output    function result.
	 * @return string
	 */
	public function add_opengraph_doctype($output)
	{
		return $output . ' xmlns:og="http://ogp.me/ns#" xmlns:fb="http://www.facebook.com/2008/fbml"';
	}

	/**
	 * SEO Opengraph function.
	 */
	public function remove_seo_opengraph()
	{
		if (class_exists('WPSEO_Installation')) {
			global $wpseo_og;
			remove_action('wpseo_head', array($GLOBALS['wpseo_og'], 'opengraph'), 30);
		}
	}

	/**
	 * Function to insert Opengraph in head.
	 */
	public function insert_opengraph_in_head()
	{
		global $wp_query;
		$settings = get_option('vpc-options');
		$url      = $_GET; // phpcs:ignore
		if (isset($url['image'])) {
			$prod_id           = $wp_query->query_vars['vpc-pid'];
			$configuration_url = rawurldecode($_SERVER['REQUEST_URI']); // phpcs:ignore
			$design_url        = vpc_get_configuration_url($prod_id);
			$share_url         = $design_url . '?image=' . $url['image'];

			echo '<meta property="og:image:type" content="image/png" />';
			echo '<meta property="og:image:width" content="781" />';
			echo '<meta property="og:image:height" content="383" />';
			echo '<meta property="og:image" content="' . esc_url($url['image']) . '"/>';
			echo '<meta property="og:type" content="Article" />';
			echo '<meta property="og:url" content="' . esc_url($share_url) . '"/>';
			echo '<meta property="fb:page_id" content="965452810483413" />';

			/*	     * Twitter metas */
			echo '<meta name="twitter:card" content="summary_large_image">';

			echo '<meta property="twitter:image:width" content="700" />';
			echo '<meta property="twitter:image:height" content="500" />';

			echo '<meta name="twitter:image" content="' . esc_url($url['image']) . '">';
			echo '<meta name="twitter:domain" content="' . esc_url($share_url) . '">';

			if (isset($settings['share-desc']) && '' !== $settings['share-desc']) {
				echo '<meta property="og:description" content="' . esc_html($settings['share-desc']) . '"/>';
			} else {
				echo '<meta property="og:description" content="' . esc_html__('An amazingly simple, yet incredibly powerful Woocommerce build your own extension which helps your customer configure or compose any product visually', 'vpc-ssa') . '"/>';
			}

			if (isset($settings['share-title-desc']) && '' !== $settings['share-title-desc']) {
				echo '<meta property="og:title" content="' . esc_html($settings['share-title-desc']) . '"/>';
				echo '<meta name="twitter:title" content="' . esc_html($settings['share-title-desc']) . '">';
			} else {
				echo '<meta name="twitter:title" content="Customize your product">';
				echo '<meta property="og:title" content="Customize your product"/>';
			}
		}
	}

	/**
	 * Function to save social share canvas image in server.
	 */
	public function vpc_ssa_save_canvas_img_in_server()
	{
		wp_verify_nonce('vpc_ssa_save_canvas_img', 'ssa_save_canvas_img_nonce');
		$recap         = array();
		$multiview     = '';
		$custom_vars   = '';
		$imgs_by_views = array();

		if (isset($_POST['recap'])) {
			$sanitize_recap = vpc_ssa_sanitize_array(wp_unslash($_POST['recap'])); // phpcs:ignore
			$recap          = vpc_ssa_clean_recap($sanitize_recap);
		}

		if (isset($_POST['imgs_by_views'])) {
			$imgs_by_views = vpc_ssa_sanitize_array(wp_unslash($_POST['imgs_by_views'])); // phpcs:ignore
		}

		if (isset($_POST['multiview']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['multiview'])))) {
			$multiview = sanitize_text_field(wp_unslash($_POST['multiview']));
		}

		if (isset($_POST['custom_vars']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['custom_vars'])))) {
			$custom_vars = $_POST['custom_vars']; // phpcs:ignore
		}

		// Remove empty compenents.
		if (isset($recap) && !empty($recap)) {
			foreach ($recap as $key => $value) {
				if ('' === $value) {
					unset($recap[$key]);
				}
			}
		}
		$preview_url      = '';
		$merged_image_url = vpc_get_merged_image($custom_vars, $multiview);
		if (isset($merged_image_url) && !empty($merged_image_url)) {
			$preview_url = vpc_get_first_element_of_array($merged_image_url);
		}
		echo wp_json_encode($preview_url);
		die();
	}

	/**
	 * Function to get social share configuration image.
	 */
	public function get_vpc_ssa_configuration_img()
	{
		wp_verify_nonce('get_configuration_img', 'get_configuration_img_nonce');
		$recap         = array();
		$prod_id       = '';
		$preview_saved = '';

		if (isset($_POST['recap'])) {
			$sanitize_recap = vpc_ssa_sanitize_array(wp_unslash($_POST['recap'])); // phpcs:ignore
			$recap          = vpc_ssa_clean_recap($sanitize_recap);
		}

		if (isset($_POST['prod_id']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['prod_id'])))) {
			$prod_id = sanitize_text_field(wp_unslash($_POST['prod_id']));
		}

		if (isset($_POST['preview_saved']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['preview_saved'])))) {
			$preview_saved = sanitize_text_field(wp_unslash($_POST['preview_saved']));
			$preview_saved = json_decode(stripslashes($preview_saved));
		}

		echo wp_json_encode($this->get_share_urls($recap, $preview_saved, $prod_id));
		die();
	}

	/**
	 * Function to add social share settings.
	 *
	 * @param array  $recap  The recap of all the selected options of a configuration.
	 * @param string $img_merged_url  A social share image url.
	 * @param int    $prod_id   product id .
	 * @return array
	 */
	private function get_share_urls($recap, $img_merged_url, $prod_id)
	{
		global $vpc_settings;
		$recap_url      = '';
		$transient_time = intval(get_proper_value($vpc_settings, 'share-time', 0));
		foreach ($recap as $component => $options) {
			$recap_url .= '&' . $component . '=';
			$recap_url .= $options;
		}
		$param      = '?image=' . $img_merged_url . $recap_url;
		$design_url = vpc_get_configuration_url($prod_id);
		$test       = explode('uploads/VPC/', $img_merged_url);
		$id         = str_replace('.png', '', $test[1]);
		$id         = str_replace('/', '', $id);

		/** Twitter share image with aq_resize. */
		$share_url = $design_url . '?image=' . $img_merged_url;

		/** Facebook share image with aq_resize. */
		$aq_img_merged_url = aq_resize($img_merged_url, 524, 273, true);
		$fb_share_url      = $design_url . '?image=' . $aq_img_merged_url;

		/** Pinterest share image with aq_resize. */
		$pin_share_url = aq_resize($img_merged_url, 240, 240, true);

		return array(
			'img_url'             => $img_merged_url,
			'facebook_share_url'  => $fb_share_url,
			'pinterest_share_url' => $design_url,
			'twitter_share_url'   => $share_url,
			'email_share_url'     => $design_url,
			'pinterest_img_url'   => $pin_share_url,
		);
	}

	/**
	 * Social share variable.
	 *
	 * @param array $datas  all datas for configuration.
	 * @return array
	 */
	public function vpc_ssa_vars($datas)
	{
		global $vpc_settings;
		$config                     = $this->get_vpc_ssa_config_data($datas['product']);
		$datas['multiviews_option'] = get_proper_value($config, 'multi-views', 'No');

		$datas['facebook_active']  = intval(get_proper_value($vpc_settings, 'facebook'));
		$datas['twitter_active']   = intval(get_proper_value($vpc_settings, 'twitter'));
		$datas['pinterest_active'] = intval(get_proper_value($vpc_settings, 'pinterest'));
		$datas['mail_active']      = intval(get_proper_value($vpc_settings, 'mail'));
		$datas['share_desc']       = get_proper_value($vpc_settings, 'share-desc');
		$datas['facebook_id']      = get_proper_value($vpc_settings, 'facebook_id');
		$datas['config_url']       = rawurldecode($_SERVER['REQUEST_URI']); // phpcs:ignore

		return $datas;
	}
}
